@@ -9,3 +9,6 @@ def write(*text, end="", split="", flush=True):
 def writeln(*text, split="", flush=True):
 	"""Print the given text to stdout, and appends a new line"""
 	write(*text, end="\n", split=split, flush=flush)
+
+def beep():
+	write("\a")
\ No newline at end of file
